<?xml version="1.0"?>
<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:doc="http://nwalsh.com/xsl/documentation/1.0"
  exclude-result-prefixes="doc"
  version="1.0">

  <doc:book xmlns="">
    <bookinfo>
      <title>XSLT Standard Library</title>
      <!-- $Id: stdlib.xsl,v 1.4 2001/04/04 06:45:16 balls Exp $ -->

      <author>
	<surname>Ball</surname>
	<firstname>Steve</firstname>
      </author>
      <copyright>
	<year>2001</year>
	<holder>Steve Ball</holder>
      </copyright>
    </bookinfo>

    <preface>
      <para>The <ulink url="http://www.w3.org/Style/XSL">XSLT</ulink> Standard Library, <acronym>xsltsl</acronym>, provides the XSLT developer with a set of XSLT templates for commonly used functions.  These are mostly implemented purely in XSLT.  Some templates call extension functions provided by XSLT processors, in order to provide a common interface.</para>
      <para>Goals of the <acronym>xsltsl</acronym> project include:</para>
      <itemizedlist>
        <listitem>
	  <para>Provision of a high-quality library of XSLT templates, suitable for inclusion by vendors in XSLT processor software products.</para>
	</listitem>
	<listitem>
	  <para>Demonstration of best practice in XSLT stylesheet development and documentation.</para>
	</listitem>
	<listitem>
	  <para>Provide examples of various techniques used to develop XSLT stylesheets (ie. a working FAQ).</para>
	</listitem>
      </itemizedlist>
    </preface>

    <chapter>
      <title>XML Namespaces</title>

      <para>Apart from the XSLT XML Namespace (http://www.w3.org/1999/XSL/Transform), <acronym>xsltsl</acronym> employs a number of XML Namespaces to allow inclusion of the library in developer stylesheets.  In addition, documentation is defined in a separate namespace.</para>
      <para>Each module is allocated a namespace URI by appending the module name to the URI for the project's SourceForge web page, http://xsltsl.sourceforge.net/.  For example, the string module has the namespace URI http://xsltsl.sourceforge.net/string.</para>
      <para>All documentation is written using <ulink url="http://www.docbook.org/">DocBook</ulink>.  The namespace URI for DocBook is http://nwalsh.com/xsl/documentation/1.0</para>
    </chapter>

    <chapter>
      <title>Engineering Standards</title>

      <para>In order to maintain a high engineering standard, all modules and contributions to the <acronym>xsltsl</acronym> project must adhere to the following coding and documentation standards.  Submissions which do not meet (or exceed) this standard will not be accepted.</para>
      <itemizedlist>
        <listitem>
          <para>All stylesheets must be indented, with each level indented by two spaces.  NB. a simple stylesheet could be used to enforce/fix this.</para>
        </listitem>
        <listitem>
          <para>Templates are named using a qualified name (QName).  The namespace URI for the template's containing stylesheet is assigned as above.</para>
        </listitem>
        <listitem>
          <para>Parameters for templates should use sensible names.  Where possible (or if in doubt), follow these conventions:</para>
          <itemizedlist>
            <listitem>
              <para>A parameter containing a single node is named <parametername>node</parametername>.  Where more than one parameter contains a single node, the suffix <parametername>Node</parametername> is appended to the parameter name, eg. <parametername>referenceNode</parametername></para>
            </listitem>
            <listitem>
              <para>A parameter which potentially contains multiple nodes is named <parametername>nodes</parametername>.  Where more than one parameter potentially contains multiple nodes, the suffix <parametername>Nodes</parametername> is appended to the parameter name, eg. <parametername>copyNodes</parametername></para>
            </listitem>
            <listitem>
              <para>A parameter which contains a string value is named <parametername>text</parametername>.</para>
            </listitem>
          </itemizedlist>
        </listitem>
        <listitem>
          <para>All templates in each stylesheet must be documented.  A template is documented as a <ulink url="http://www.docbook.org/">DocBook</ulink> RefEntry.</para>
        </listitem>
        <listitem>
          <para>Every stylesheet must include a test suite.  The test system is in the <filename>test</filename> subdirectory.  See <ulink url="test/test.html">test/test.html</ulink> for further details.</para>
        </listitem>
      </itemizedlist>
    </chapter>

    <chapter>
      <title>Reference Documentation</title>

      <para>Reference documentation is available for each module.</para>

      <section>
	<title>String Processing</title>

	<itemizedlist>
	  <listitem>
	    <para><ulink url="string.html">string.xsl</ulink></para>
	  </listitem>

	  <listitem>
	    <para><ulink url="date-time.html">dates.xsl</ulink></para>
	  </listitem>

	</itemizedlist>
      </section>

<!--
      <section>
        <title>Presentation Media Support</title>

        <itemizedlist>
          <listitem>
            <para><ulink url="html/html.html">html/html.xsl</ulink></para>
          </listitem>
          <listitem>
            <para><ulink url="fo/fo.html">fo/fo.xsl</ulink></para>
          </listitem>
        </itemizedlist>
      </section>
-->

    </chapter>

  </doc:book>

  <xsl:import href="string.xsl"/>
  <xsl:import href="date-time.xsl"/>

<!--
  <xsl:import href="html/html.xsl"/>
  <xsl:import href="fo/fo.xsl"/>
-->

</xsl:stylesheet>
