<?xml version="1.0"?>
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:doc="http://nwalsh.com/xsl/documentation/1.0"
	xmlns:str="http://xsltsl.sourceforge.net/string"
	exclude-result-prefixes="doc"
	version="1.0">

  <xsl:include href="../string.xsl"/>

  <doc:article>
    <doc:title>String Module Test Suite</doc:title>

    <doc:para>This stylesheet tests the string stylesheet module.</doc:para>
  </doc:article>

  <xsl:template name="string">
    <xsl:message>String tests starting</xsl:message>
    <xsl:text>Running string tests

</xsl:text>

    <xsl:message>Test str:to-lower template</xsl:message>

    <xsl:call-template name="test">

      <xsl:with-param name="description">str:to-lower test</xsl:with-param>

      <xsl:with-param name="result">
        <xsl:call-template name="str:to-lower">
	  <xsl:with-param name="text">tHiS iS a TeSt</xsl:with-param>
        </xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">this is a test</xsl:with-param>

    </xsl:call-template>
    <xsl:call-template name="test">

      <xsl:with-param name="description">str:to-lower test (empty string)</xsl:with-param>

      <xsl:with-param name="result">
        <xsl:call-template name="str:to-lower">
	  <xsl:with-param name="text"/>
        </xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect"/>

    </xsl:call-template>

    <xsl:message>Test str:to-upper template</xsl:message>

    <xsl:call-template name="test">

      <xsl:with-param name="description">str:to-upper test</xsl:with-param>

      <xsl:with-param name="result">
        <xsl:call-template name="str:to-upper">
	  <xsl:with-param name="text">tHiS iS a TeSt</xsl:with-param>
        </xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">THIS IS A TEST</xsl:with-param>

    </xsl:call-template>
    <xsl:call-template name="test">

      <xsl:with-param name="description">str:to-upper test (empty string)</xsl:with-param>

      <xsl:with-param name="result">
        <xsl:call-template name="str:to-upper">
	  <xsl:with-param name="text"/>
        </xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect"/>

    </xsl:call-template>

    <xsl:message>Test str:capitalise template</xsl:message>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:capitalise test</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:capitalise">
	  <xsl:with-param name="text">capITAL</xsl:with-param>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">Capital</xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:capitalise test (empty string)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:capitalise"/>
      </xsl:with-param>

      <xsl:with-param name="expect"/>
    </xsl:call-template>

    <xsl:message>Test str:subst template</xsl:message>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:subst test (no replacements)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:subst">
	  <xsl:with-param name="text">This is a test</xsl:with-param>
	  <xsl:with-param name="replace">foo</xsl:with-param>
	  <xsl:with-param name="with">bar</xsl:with-param>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">This is a test</xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:subst test (one replacement)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:subst">
	  <xsl:with-param name="text">This is a test</xsl:with-param>
	  <xsl:with-param name="replace"> is</xsl:with-param>
	  <xsl:with-param name="with"> was</xsl:with-param>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">This was a test</xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:subst test (mutliple replacements)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:subst">
	  <xsl:with-param name="text">This is a test, This is a test, This is a test, This is a test</xsl:with-param>
	  <xsl:with-param name="replace">test</xsl:with-param>
	  <xsl:with-param name="with">success</xsl:with-param>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">This is a success, This is a success, This is a success, This is a success</xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:subst test (empty string)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:subst">
	  <xsl:with-param name="text"/>
	  <xsl:with-param name="replace">foo</xsl:with-param>
	  <xsl:with-param name="with">bar</xsl:with-param>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect"/>
    </xsl:call-template>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:subst test (empty with)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:subst">
	  <xsl:with-param name="text">This is a test</xsl:with-param>
	  <xsl:with-param name="replace">is</xsl:with-param>
	  <xsl:with-param name="with"/>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">Th  a test</xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="test">
      <xsl:with-param name="description">str:subst test (empty replace)</xsl:with-param>

      <xsl:with-param name="result">
	<xsl:call-template name="str:subst">
	  <xsl:with-param name="text">This is a test</xsl:with-param>
	  <xsl:with-param name="replace"/>
	  <xsl:with-param name="with">foobar</xsl:with-param>
	</xsl:call-template>
      </xsl:with-param>

      <xsl:with-param name="expect">This is a tes</xsl:with-param>
    </xsl:call-template>

  </xsl:template>

</xsl:stylesheet>
